#################
Library Reference
#################

Compute and Data Services
*************************

Some propper discussion what compute and data services are and how they are supposed to
be used needs to go here. The 'aggregate' ComputeDataService needs to be explained here
as well! And examples! Examples are always good.

.. autoclass:: pilot.impl.pilotcompute_manager.PilotComputeService
   :members:

.. autoclass:: pilot.impl.pilotdata_manager.PilotDataService
   :members:

.. autoclass:: pilot.impl.pilot_manager.ComputeDataService
   :members:
